Module context

Module context 

Invocation context management for span correlation.

This module provides the central coordinator for correlating platform spans with function spans. It uses state-based correlation with watch channels for timeout-bounded waiting.

Structs

InvocationContextManager
Central coordinator for correlating platform spans with function spans.
PlatformEvent
Platform event received from the Lambda Telemetry API.
SpanContext
Span context information extracted from a parent span.

Enums

PlatformEventType
Types of platform events from the Telemetry API.

Type Aliases

RequestId
Unique identifier for a Lambda invocation request.