pub struct OtlpReceiver { /* private fields */ }Expand description
OTLP HTTP receiver for collecting signals.
Implementations
Sourceimpl OtlpReceiver
impl OtlpReceiver
Sourcepub fn new(
config: ReceiverConfig,
signal_tx: Sender<Signal>,
cancel_token: CancellationToken,
) -> Self
pub fn new( config: ReceiverConfig, signal_tx: Sender<Signal>, cancel_token: CancellationToken, ) -> Self
Creates a new OTLP receiver.
Arguments
config- Receiver configurationsignal_tx- Channel for sending received signals to the aggregatorcancel_token- Token for graceful shutdown
Sourcepub async fn start(
self,
) -> Result<(ReceiverHandle, Pin<Box<dyn Future<Output = ()> + Send>>), Error>
pub async fn start( self, ) -> Result<(ReceiverHandle, Pin<Box<dyn Future<Output = ()> + Send>>), Error>
Starts the HTTP receiver and returns a handle for interacting with it.
The handle can be used to query the receiver’s status, trigger flushes, and get the actual bound address.
Returns
Returns Ok((handle, future)) where handle can be used to interact with
the receiver and future should be spawned to run the server.
Errors
Returns an error if the server fails to bind to the address.