Re-export semantic conventions for use by other modules.
Constants
- AWS_
LOG_ GROUP_ NAMES - The name(s) of the AWS log group(s) an application is writing to.
- AWS_
LOG_ STREAM_ NAMES - The name(s) of the AWS log stream(s) an application is writing to.
- CLOUD_
PLATFORM - The cloud platform in use.
- CLOUD_
PROVIDER - Name of the cloud provider.
- CLOUD_
REGION - The geographical region within a cloud provider. When associated with a resource, this attribute specifies the region where the resource operates. When calling services or APIs deployed on a cloud, this attribute identifies the region where the called destination is deployed.
- FAAS_
COLDSTART - A boolean that is true if the serverless function is executed for the first time (aka cold-start).
- FAAS_
INSTANCE - The execution environment ID as a string, that will be potentially reused for other invocations to the same function/function version.
- FAAS_
INVOCATION_ ID - The invocation ID of the current function invocation.
- FAAS_
MAX_ MEMORY - The amount of memory available to the serverless function converted to Bytes.
- FAAS_
NAME - The name of the single function that this runtime instance executes.
- FAAS_
TRIGGER - Type of the trigger which caused this function invocation.
- FAAS_
VERSION - The immutable version of the function being executed.
- SERVICE_
NAME - Logical name of the service.
- TELEMETRY_
SDK_ LANGUAGE - The language of the telemetry SDK.
- TELEMETRY_
SDK_ NAME - The name of the telemetry SDK as defined above.
- TELEMETRY_
SDK_ VERSION - The version string of the telemetry SDK.