pub struct TelemetryService { /* private fields */ }Expand description
Tower service for processing Lambda Telemetry API events.
This service receives platform telemetry events and converts them to OTLP metrics and traces, adding them to the aggregator for export.
Implementations
Sourceimpl TelemetryService
impl TelemetryService
Sourcepub fn new(state: Arc<ExtensionState>) -> Self
pub fn new(state: Arc<ExtensionState>) -> Self
Creates a new telemetry service with the given shared state.