pub struct ExportFailure {
pub error: Box<dyn Error + Sync + Send>,
pub request: FailedRequest,
pub timestamp: SystemTime,
}Expand description
Details of a failed export after all retry attempts have been exhausted.
Fields
error: Box<dyn Error + Sync + Send>The error that caused the export to fail.
request: FailedRequestThe original OTLP request that failed to export.
This contains the full payload ready to be serialised and sent via an alternative transport.
timestamp: SystemTimeWhen the failure occurred.
Implementations
Sourceimpl ExportFailure
impl ExportFailure
Sourcepub fn new(
error: impl Into<Box<dyn Error + Sync + Send>>,
request: FailedRequest,
) -> ExportFailure
pub fn new( error: impl Into<Box<dyn Error + Sync + Send>>, request: FailedRequest, ) -> ExportFailure
Creates a new export failure.
Sourcepub fn size_bytes(&self) -> usize
pub fn size_bytes(&self) -> usize
Returns the size of the failed request in bytes.
Sourcepub fn error_message(&self) -> String
pub fn error_message(&self) -> String
Returns the error message as a string.