ExportFailure

Struct ExportFailure 

pub struct ExportFailure {
    pub error: Box<dyn Error + Sync + Send>,
    pub request: FailedRequest,
    pub timestamp: SystemTime,
}
Details of a failed export after all retry attempts have been exhausted.

Fields

error: Box<dyn Error + Sync + Send>

The error that caused the export to fail.

request: FailedRequest

The original OTLP request that failed to export.

This contains the full payload ready to be serialised and sent via an alternative transport.

timestamp: SystemTime

When the failure occurred.

Implementations

Source

impl ExportFailure

pub fn new( error: impl Into<Box<dyn Error + Sync + Send>>, request: FailedRequest, ) -> ExportFailure

Creates a new export failure.

pub fn size_bytes(&self) -> usize

Returns the size of the failed request in bytes.

pub fn error_message(&self) -> String

Returns the error message as a string.